pub fn assert_pyth_receiver_owner(info: &AccountInfo<'_>) -> ProgramResultExpand description
Assert that info is owned by either the Pyth Receiver program (pull feeds) or the
Pyth Push Oracle program (continuously-maintained push feed accounts).
pub fn assert_pyth_receiver_owner(info: &AccountInfo<'_>) -> ProgramResultAssert that info is owned by either the Pyth Receiver program (pull feeds) or the
Pyth Push Oracle program (continuously-maintained push feed accounts).