pub fn refund_void_position(
authority: Pubkey,
series_id: u16,
period: u64,
position_owner: Pubkey,
) -> InstructionExpand description
Builds AdminRefundVoidPosition. authority must be crate::consts::EXECUTOR_ADDRESS.
Refunds position_owner’s STATE_PENDING position in a voided market back to their Ledger.
Iterate all stakers and call this once per position.